@@ -61,8 +61,8 @@ default_options.__dict__ = {
         'filename': None,
         'first_page_author_org': True,
         'html': False,
-        'id_base_url': 'https://tools.ietf.org/html/',
-        'id_reference_base_url': 'https://tools.ietf.org/html/',
+        'id_base_url': 'https://datatracker.ietf.org/doc/html/',
+        'id_reference_base_url': 'https://datatracker.ietf.org/doc/html/',
         'id_is_work_in_progress': True,
         'image_svg': False,
         'indent': 2,
@@ -2216,3 +2216,41 @@ class BaseV3Writer(object):
                 p.text = (p.text or '') + e.tail
         p.remove(e)
 
+    @staticmethod
+    def split_pn(pn):
+        """Split a pn into meaningful parts
+
+        Returns a tuple (element_type, section_number, paragraph_number).
+        If there is no paragraph number, it will be None.
+        """
+        parts = pn.split('-', 2)
+        elt_type = parts[0]
+        sect_num = parts[1]
+        paragraph_num = parts[2] if len(parts) > 2 else None
+
+        # see if section num needs special handling
+        components = sect_num.split('.', 1)
+        if components[0] in ['appendix', 'boilerplate', 'note', 'toc']:
+            sect_num = components[1]  # these always have a second component
+        return elt_type, sect_num, paragraph_num
+
+    @staticmethod
+    def level_of_section_num(num):
+        """Determine hierarchy level of a section number
+
+        Top level items have level 1. N.B., num is a string.
+        """
+        num_with_no_trailing_dot = num.rstrip('.')
+        components = num_with_no_trailing_dot.split('.')
+        if any([len(cpt) == 0 for cpt in components]):
+            log.warn('Empty section number component in "{}"'.format(num))
+        return len(components)
+
+    @classmethod
+    def is_top_level_section(cls, num):
+        return cls.level_of_section_num(num) == 1
+
+    @staticmethod
+    def is_appendix(pn):
+        """Is a section with this number an appendix?"""
+        return pn.startswith('section-appendix.')
